@@ -34,16 +34,39 @@
 #define RESULTSWINDOW_H
 
 // qt includes
-#include <QtGui/QMainWindow>
-#include <QSet>
+#include <QtGui>
 // local includes
 
-class SinkPlugin;
+class PluginAction;
 
 namespace Ui {
     class ResultsWindow;
 }
+class PluginActionListModel : public QAbstractListModel {
+    Q_OBJECT
+public:
+    PluginActionListModel(QObject *parent = 0, QList<PluginAction *>list = QList<PluginAction *>())
+        : QAbstractListModel(parent) {
+        plugin_list = list;
+    }
+    int rowCount(const QModelIndex &model = QModelIndex()) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+public slots:
 
+private:
+    QList<PluginAction *> plugin_list;
+};
+class PluginActionListDelegate : public QStyledItemDelegate {
+Q_OBJECT
+
+public:
+PluginActionListDelegate(QObject *parent = 0)
+    : QStyledItemDelegate(parent) {}
+
+void paint(QPainter *painter, const QStyleOptionViewItem &option,
+           const QModelIndex &index) const;
+QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index);
+};
 class ResultsWindow : public QMainWindow {
     Q_OBJECT
 public:
@@ -51,21 +74,22 @@ public:
     ~ResultsWindow();
 
     void processBarcode(QString barcode);
-    void setSinkPlugins(QSet<SinkPlugin*> plugins);
+    void setPluginActions(QList<PluginAction*> plugins);
 
 protected:
     void changeEvent(QEvent *e);
 
 private:
-    QSet<SinkPlugin*> plugins;
-    QSet<SinkPlugin*> addedPlugins;
+    QList<PluginAction*> plugins;
+    QList<PluginAction*> addedPlugins;
 
-    Ui::ResultsWindow *m_ui;
+    Ui::ResultsWindow *ui;
     QTimer *checkTimer;
 
     QString barcode_text;
 
 private slots:
+    void on_tblResults_clicked(QModelIndex index);
     void on_pushButton_clicked();
     void checkPlugins(); // called by a timer to see if there are any plugins which are ready
 };
